package lab6;

import javax.swing.*;
import java.awt.*;

public class ViewBeatStatus extends JPanel 
{
	private static final String ONHEART = "resources/onheart.jpg";
	private static final String OFFHEART = "resources/offheart.jpg";

	private static final long serialVersionUID = 1;

	private Image onImage, offImage;
	private boolean state;
	private Dimension size;

	public ViewBeatStatus()
	{
		super();

		onImage = Toolkit.getDefaultToolkit().getImage(getClass().getResource(ONHEART));
		offImage = Toolkit.getDefaultToolkit().getImage(getClass().getResource(OFFHEART));
		state = false;
		
		// wait for images to load
		MediaTracker mt = new MediaTracker(this);
		mt.addImage(onImage, 0);
		mt.addImage(offImage, 0);
		try {
			mt.waitForAll();
		} catch(InterruptedException e) {}

		// assume that both images have the same size
		size = new Dimension(onImage.getWidth(this), onImage.getHeight(this));
		
		this.setSize(size);
	}

	/**
	 * Change the state of the image being displayed. Either the on or off image
	 * is displayed depending on the value of state
	 * 
	 * @param state choose which image to display
	 */
	public void setState(boolean state)
	{
		if(state != this.state) 
		{
			this.state = state;
			this.repaint();
		}
	}

	/**
	 * Return the current value of the state
	 * 
	 * @return the current value of the image state.
	 */
	public boolean getState()
	{
		return this.state;
	}

	@Override
	public void paintComponent(Graphics g)
	{
		if(state)
			g.drawImage(onImage, 0, 0, this.getWidth(), this.getHeight(), null);
		else
			g.drawImage(offImage,  0,  0,  this.getWidth(), this.getHeight(), null);
	}

	@Override
	public Dimension getPreferredSize()
	{
		return size;
	}
}
